from setuptools import setup

setup(name='TS_distributions',
      version='1.1',
      description='Gaussian & Binomial distributions',
      packages=['TS_distributions'],
      author = 'Tarun Saxena',
      author_email = 'tarunsaxena16@gmail.com',
      zip_safe=False)
